use derive_more::{Add, AddAssign, Display, Sub, SubAssign};
use crate::quantity::{Quantity, Value};

// ---------------------------------------------------------------------------------------------------------------------
// ----- Watts per Square Meter ------------------------
// ---------------------------------------------------------------------------------------------------------------------
#[derive(Copy, Clone, PartialEq, PartialOrd, Add, AddAssign, Sub, SubAssign, Display)]
#[display(fmt = "{} {}", _0, "Self::symbol()")]
#[repr(transparent)]
pub struct WattsPerSquareMeter<V: Value>(pub V);

impl <V: Value> Quantity<V> for WattsPerSquareMeter<V> {
    #[inline(always)]
    fn value(self) -> V {
        self.0
    }

    #[inline(always)]
    fn symbol() -> &'static str {
        "W/m²"
    }
}